# Column Cleaner for a Dataframe
 
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)   

## Functionality of the Column Cleaner

- It will replace space with "_".
- It will remove the numbers.


## Usage

- Make sure you have Python installed in your system.
- Run Following command in the CMD.
 ```
  pip install column_cleaner
  ```

## Note 
- I have tried to implement all the functionality, it might have some bugs also. Ignore that or please try to solve that bug.
